.. asammdf documentation master file, created by
   sphinx-quickstart on Wed Jul 12 06:05:15 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to asammdf's documentation!
===================================

`asammdf` is a fast parser and editor for ASAM (Association for Standardization of Automation and Measuring Systems) MDF (Measurement Data Format) files.

`asammdf` supports MDF versions 2 (.dat), 3 (.mdf) and 4 (.mf4).

`asammdf` works on Python >= 3.10 (for Python 2.7, 3.4 and 3.5 see the 4.x.y releases)


.. toctree::
   :maxdepth: 4

   intro
   api
   buslogging
   tips
   examples
   benchmarks
   gui
   functions_manager


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
